[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --local-branching-on-the-cheap
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
#  Tools
The community has built a huge number of tools to make it easier to use Git. While you can use Git on its own, most Git users use some of these extra tools. There are editor integrations, GUIs, tools for resolving merge conflicts, hosting services, and much more.
[ ![Terminal icon](https://git-scm.com/images/icons/fa-terminal.svg) Command Line Tools  ](https://git-scm.com/tools/command-line)
Tools to view and manipulate your Git history
[ ![Desktop icon](https://git-scm.com/images/icons/fa-desktop.svg) GUIs  ](https://git-scm.com/tools/guis)
Graphical user interfaces and editor integrations
[ ![Cloud icon](https://git-scm.com/images/icons/fa-cloud.svg) Hosting  ](https://git-scm.com/tools/hosting)
Git repository hosting
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
